# History

## 0.2.1 (2021-12-13)

- Fix incorrct type checking placement.

## 0.2.0 (2021-12-13)

-   Improve argument handling.
-   Improve readme.
-   Update PyPI classifiers.

## 0.1.0 (2021-12-12)

-   First release on PyPI.
